summaryrefslogtreecommitdiff
path: root/deps/v8/src/mark-compact.h
diff options
context:
space:
mode:
authorRyan Dahl <ry@tinyclouds.org>2010-04-14 10:34:17 -0700
committerRyan Dahl <ry@tinyclouds.org>2010-04-14 10:34:27 -0700
commit41ef1717e096a9e1761efa0df97c395f59c51f16 (patch)
tree7e854284ef8ce5189a63074857a408b6eea5a9cb /deps/v8/src/mark-compact.h
parent760bba55186eba039ca00e532f7813d2aea450a2 (diff)
downloadnode-new-41ef1717e096a9e1761efa0df97c395f59c51f16.tar.gz
Upgrade V8 to 2.2.3.1
Diffstat (limited to 'deps/v8/src/mark-compact.h')
-rw-r--r--deps/v8/src/mark-compact.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/deps/v8/src/mark-compact.h b/deps/v8/src/mark-compact.h
index ab572f6997..27335f2a09 100644
--- a/deps/v8/src/mark-compact.h
+++ b/deps/v8/src/mark-compact.h
@@ -407,26 +407,26 @@ class MarkCompactCollector: public AllStatic {
// Counters used for debugging the marking phase of mark-compact or
// mark-sweep collection.
- // Number of live objects in Heap::to_space_.
- static int live_young_objects_;
+ // Size of live objects in Heap::to_space_.
+ static int live_young_objects_size_;
- // Number of live objects in Heap::old_pointer_space_.
- static int live_old_pointer_objects_;
+ // Size of live objects in Heap::old_pointer_space_.
+ static int live_old_pointer_objects_size_;
- // Number of live objects in Heap::old_data_space_.
- static int live_old_data_objects_;
+ // Size of live objects in Heap::old_data_space_.
+ static int live_old_data_objects_size_;
- // Number of live objects in Heap::code_space_.
- static int live_code_objects_;
+ // Size of live objects in Heap::code_space_.
+ static int live_code_objects_size_;
- // Number of live objects in Heap::map_space_.
- static int live_map_objects_;
+ // Size of live objects in Heap::map_space_.
+ static int live_map_objects_size_;
- // Number of live objects in Heap::cell_space_.
- static int live_cell_objects_;
+ // Size of live objects in Heap::cell_space_.
+ static int live_cell_objects_size_;
- // Number of live objects in Heap::lo_space_.
- static int live_lo_objects_;
+ // Size of live objects in Heap::lo_space_.
+ static int live_lo_objects_size_;
// Number of live bytes in this collection.
static int live_bytes_;